Discover Packages
github.com/Alonso-Arias/test-amaris
services
model
package
Version:
v0.0.0-...-29a42cb
Opens a new window with list of versions in this module.
Published: Nov 21, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Pokemon struct {
ID int `json:"id"`
Type string `json:"type"`
Ability string `json:"ability"`
Strength string `json:"strength"`
Moves string `json:"moves"`
}
swagger:model Pokemon
type PokemonExternal struct {
ID int `json:"id"`
IsBattleOnly bool `json:"is_battle_only"`
IsDefault bool `json:"is_default"`
IsMega bool `json:"is_mega"`
Pokemon interface{} `json:"pokemon"`
VersionGroup struct {
Name string `json:"name"`
} `json:"version_group"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.